# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [0.1.0](https://github.com/mkdocstrings/griffe-sphinx/releases/tag/0.1.0) - 2024-08-10

<small>[Compare with first commit](https://github.com/mkdocstrings/griffe-sphinx/compare/cc9bc696325f8d59be9710a9515e136d2483826b...0.1.0)</small>

### Features

- Implement no-op extension ([da0ef37](https://github.com/mkdocstrings/griffe-sphinx/commit/da0ef3746d53c37a299a33267cdd2f2047237ffe) by Timothée Mazzucotelli).
- Generate project with gh:pawamoy/copier-uv Copier template ([cc9bc69](https://github.com/mkdocstrings/griffe-sphinx/commit/cc9bc696325f8d59be9710a9515e136d2483826b) by Timothée Mazzucotelli).
